@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: X11
-version: 1.6.0
-id: X11-1.6.0-34d5fa7e6b479ed438484c2315a89d50
+version: 1.6.1.1
+id: X11-1.6.1.1-4a4f242486ab0f5871a70bcb05fc9b64
 
 license: BSD3
 copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
@@ -9,6 +9,7 @@ maintainer: Daniel Wagner <daniel@wagner-home.com>
 stability:
 homepage: https://github.com/haskell-pkg-janitors/X11
 package-url:
+synopsis: A binding to the X11 graphics library
 description: A Haskell binding to the X11 graphics library.
              The binding is a direct translation of the C binding; for
              documentation of these calls, refer to "The Xlib Programming
@@ -25,25 +26,27 @@ exposed-modules: Graphics.X11 Graphics.X11.Types Graphics.X11.Xlib
                  Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
                  Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
                  Graphics.X11.Xlib.Image Graphics.X11.Xlib.Extras
-                 Graphics.X11.Xinerama Graphics.X11.Xrandr Graphics.X11.ExtraTypes
-                 Graphics.X11.ExtraTypes.AP Graphics.X11.ExtraTypes.DEC
-                 Graphics.X11.ExtraTypes.HP Graphics.X11.ExtraTypes.Sun
-                 Graphics.X11.ExtraTypes.XF86 Graphics.X11.ExtraTypes.XorgDefault
-hidden-modules:
-import-dirs: /usr/local/lib/ghc/X11-1.6.0
-library-dirs: /usr/local/lib/ghc/X11-1.6.0
-hs-libraries: HSX11-1.6.0
-extra-libraries: Xinerama Xext X11 Xrandr Xext
+                 Graphics.X11.Xinerama Graphics.X11.Xrandr Graphics.X11.XScreenSaver
+                 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
+                 Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
+                 Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
+                 Graphics.X11.ExtraTypes.XorgDefault
+hidden-modules: Graphics.X11.Xlib.Internal
+trusted: False
+import-dirs: /usr/local/lib/ghc/X11-1.6.1.1
+library-dirs: /usr/local/lib/ghc/X11-1.6.1.1
+hs-libraries: HSX11-1.6.1.1
+extra-libraries: Xss Xinerama Xext X11 Xrandr Xext
 extra-ghci-libraries:
-include-dirs: /usr/local/lib/ghc/X11-1.6.0/include
+include-dirs: /usr/local/lib/ghc/X11-1.6.1.1/include
 includes: HsXlib.h HsAllKeysyms.h
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         syb-0.3.3-dd575fa8180bf87dbbe1727117c3b35c
+depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         data-default-0.5.1-3dcf8b1e18d6ff182bcfe57129991c1d
 hugs-options:
 cc-options:
 ld-options: -L/usr/X11R6/lib -R/usr/X11R6/lib
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-X11-1.6.0/html/X11.haddock
-haddock-html: /usr/local/share/doc/hs-X11-1.6.0/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-X11-1.6.1.1/html/X11.haddock
+haddock-html: /usr/local/share/doc/hs-X11-1.6.1.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
